//======================================================================================================================
//
//  This file is part of waLBerla. waLBerla is free software: you can
//  redistribute it and/or modify it under the terms of the GNU General Public
//  License as published by the Free Software Foundation, either version 3 of
//  the License, or (at your option) any later version.
//
//  waLBerla is distributed in the hope that it will be useful, but WITHOUT
//  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
//  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
//  for more details.
//
//  You should have received a copy of the GNU General Public License along
//  with waLBerla (see COPYING.txt). If not, see <http://www.gnu.org/licenses/>.
//
//! \file Types.h
//! \author Markus Holzer <markus.holzer@fau.de>
//
//======================================================================================================================
# pragma once

#include "domain_decomposition/BlockDataID.h"
#include "lbm_generated/field/PdfField.h"
#include "PorousMediaGPUInfoHeader.h"

using namespace walberla;

using StorageSpecification_T = lbm::PorousMediaGPUStorageSpecification;
using Stencil_T              = StorageSpecification_T::Stencil;
using CommunicationStencil_T = StorageSpecification_T::CommunicationStencil;

using PdfField_T           = lbm_generated::PdfField< StorageSpecification_T >;
using FlagField_T          = FlagField< uint8_t >;

using BoundaryCollection_T = lbm::PorousMediaGPUBoundaryCollection< FlagField_T >;
using SweepCollection_T = lbm::PorousMediaGPUSweepCollection;
using WelfordSweep_T = pystencils::Welford;

using macroFieldType = VelocityField_T::value_type;

#if defined(WALBERLA_BUILD_WITH_GPU_SUPPORT)
#include "lbm_generated/gpu/GPUPdfField.h"
using GPUPdfField_T = lbm_generated::GPUPdfField< StorageSpecification_T >;
using GPUField_T = gpu::GPUField< VelocityField_T::value_type >;
using GPUFlagField_T = gpu::GPUField< FlagField_T::value_type >;
#endif

struct IDs
{
   BlockDataID pdfField;
   BlockDataID velocityField;
   BlockDataID meanVelocityField;
   BlockDataID sosField;
   BlockDataID velocityFieldInflowSlice;
   BlockDataID densityField;
   BlockDataID flagField;

   BlockDataID pdfFieldGPU;
   BlockDataID velocityFieldGPU;
   BlockDataID meanVelocityFieldGPU;
   BlockDataID sosFieldGPU;
   BlockDataID velocityFieldInflowSliceGPU;
   BlockDataID densityFieldGPU;
   BlockDataID flagFieldGPU;
};