//======================================================================================================================
//
//  This file is part of waLBerla. waLBerla is free software: you can
//  redistribute it and/or modify it under the terms of the GNU General Public
//  License as published by the Free Software Foundation, either version 3 of
//  the License, or (at your option) any later version.
//
//  waLBerla is distributed in the hope that it will be useful, but WITHOUT
//  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
//  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
//  for more details.
//
//  You should have received a copy of the GNU General Public License along
//  with waLBerla (see COPYING.txt). If not, see <http://www.gnu.org/licenses/>.
//
//! \file util.h
//! \author Markus Holzer <markus.holzer@fau.de>
//
//======================================================================================================================
#pragma once

#include "core/DataTypes.h"
#include "core/math/Constants.h"
#include "core/math/Vector3.h"
#include "core/math/Random.h"
#include "core/math/AABB.h"

namespace walberla{
Vector3<real_t> summOfFourrierModes(const Vector3<real_t>& p, const Vector3<real_t>& uc,
                                    const std::vector<real_t>& kappa, const std::vector<real_t>& ut, const real_t t);

real_t getKarmanPaoEnergy(const real_t k, const real_t alpha, const real_t kappaVKP, const real_t kappaKolmogorov, const real_t uRMS);

Vector3<real_t> getCenterOfHemisphere(const Vector3<real_t>& p, const real_t hemispheresDistance,
                                      const real_t domainYMin, const real_t domainYMax);

bool hemispheresContains(const Vector3<real_t>& point, const Vector3<real_t>& center, const real_t radius);
void getAllHemisphereCenters(std::vector<Vector3<real_t>>& centers, const real_t hemispheresRadius, const real_t hemispheresDistance, const math::AABB& domain);     

real_t calculateDrivingForce(const real_t targetFrictionVelocity, const real_t referenceLenght, const real_t targetBulkVelocity, const real_t bulkVelocity);

void renameFile(const std::string& oldName, const std::string& newName);

} // namespace walberla