//======================================================================================================================
//
//  This file is part of waLBerla. waLBerla is free software: you can 
//  redistribute it and/or modify it under the terms of the GNU General Public
//  License as published by the Free Software Foundation, either version 3 of 
//  the License, or (at your option) any later version.
//  
//  waLBerla is distributed in the hope that it will be useful, but WITHOUT 
//  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
//  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License 
//  for more details.
//  
//  You should have received a copy of the GNU General Public License along
//  with waLBerla (see COPYING.txt). If not, see <http://www.gnu.org/licenses/>.
//
//! \file hdfWrapper.h
//! \ingroup postprocessing
//! \author Markus Holzer <markus.holzer@fau.de>
//
//======================================================================================================================
#include "hdfWrapper.h"

namespace walberla::io{

hdfFile createHdf5file(const filesystem::path& filepath){
    
  H5::FileAccPropList fileAccProps;

#ifdef WALBERLA_BUILD_WITH_MPI
    //  Enable MPI-IO
    H5Pset_fapl_mpio(fileAccProps.getId(), mpi::MPIManager::instance()->comm(), MPI_INFO_NULL);
#endif

  //  All MPI processes collectively create and prepare the file
  return H5::H5File(filepath.c_str(), H5F_ACC_CREAT | H5F_ACC_RDWR, H5::FileCreatPropList::DEFAULT, fileAccProps);

}

H5::FloatType h5Double(){return H5::FloatType(H5::PredType::NATIVE_DOUBLE);}
H5::FloatType h5Float(){return H5::FloatType(H5::PredType::NATIVE_FLOAT);}
H5::FloatType h5FileFloat(){return H5::FloatType(H5::PredType::IEEE_F32LE);}


}