//======================================================================================================================
//
//  This file is part of waLBerla. waLBerla is free software: you can 
//  redistribute it and/or modify it under the terms of the GNU General Public
//  License as published by the Free Software Foundation, either version 3 of 
//  the License, or (at your option) any later version.
//  
//  waLBerla is distributed in the hope that it will be useful, but WITHOUT 
//  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
//  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License 
//  for more details.
//  
//  You should have received a copy of the GNU General Public License along
//  with waLBerla (see COPYING.txt). If not, see <http://www.gnu.org/licenses/>.
//
//! \file hdfWrapper.h
//! \ingroup postprocessing
//! \author Markus Holzer <markus.holzer@fau.de>
//
//======================================================================================================================
#pragma once

#include "core/mpi/MPIManager.h"
#include "core/mpi/MPIWrapper.h"
#include "core/Filesystem.h"

#include <H5Cpp.h>


namespace walberla::io{

using hdfFile = H5::H5File;
hdfFile createHdf5file(const filesystem::path& filepath);

H5::FloatType h5Double();
H5::FloatType h5Float();
H5::FloatType h5FileFloat();

template< typename T >
H5::DataType getH5ExportType();

template<>
inline H5::DataType getH5ExportType< uint8_t >()
{
  return H5::FloatType(H5::PredType::STD_U8LE);
}

template<>
inline H5::DataType getH5ExportType< float >()
{
  return H5::FloatType(H5::PredType::IEEE_F32LE);
}

template<>
inline H5::DataType getH5ExportType< double >()
{
  return H5::FloatType(H5::PredType::IEEE_F64LE);
}




}